pub struct Error(/* private fields */);Expand description
Wrapper type for handling different Vouched error types uniformly.
This allows code that works with multiple Vouched wrappers to handle their
validation errors through a single type. It supports automatic conversion
through the ? operator.
Available with the alloc feature, which is enabled by the default std
feature.
Examples
// Function that handles different Vouched error types uniformly.
fn process_errors() -> Result<(), Error> {
// Any error implementing VouchedError can be converted into Error.
let err = UserIdError::TooShort(TooShortError::new(1, 0));
Err(Error::from(err))
}
// Inspect the concrete validation error kind.
let result = process_errors();
assert!(result.is_err());
let err = result.unwrap_err();
assert!(err.as_too_short().is_some());Implementations
Sourceimpl Error
impl Error
Sourcepub fn new(inner: Box<dyn VouchedError>) -> Error
pub fn new(inner: Box<dyn VouchedError>) -> Error
Wraps a boxed generated Vouched error.
Sourcepub fn into_inner(self) -> Box<dyn VouchedError>
pub fn into_inner(self) -> Box<dyn VouchedError>
Returns the wrapped generated Vouched error.